@@ -1,8 +1,13 @@
-from typing import List
+from typing import List, Optional
 
 from byteplussdkarkruntime._models import BaseModel
 
-__all__ = ["ImagesResponse"]
+__all__ = ["SequentialImageGenerationOptions", "ImagesResponse"]
+
+
+class SequentialImageGenerationOptions(BaseModel):
+    max_images: Optional[int] = None
+    """ Maximum number of images to generate in this request; effective only when the multi-image feature is enabled """
 
 
 class Usage(BaseModel):
@@ -17,6 +22,9 @@ class Image(BaseModel):
     b64_json: str
     """The Base 64 encoded string of the generated image, if any."""
 
+    size: str
+    """The size of the generated image, if any."""
+
 
 class Error(BaseModel):
     message: str
